@@ -3,15 +3,10 @@
 class Accumulator {
 	var $queryListeners = array();
 	var $errorListeners = array();
-	var $hasDurationInfo = false;
 	
 	function append(& $line) {
 	}
 	
-	function hasDurationInfo() {
-		return $this->hasDurationInfo;
-	}
-	
 	function addQueryListener(& $queryListener) {
 		$this->queryListeners[] =& $queryListener;
 	}
