@@ -1,5 +1,7 @@
 <?php
 
+require_once('lib/Profiler.class.php');
+
 require_once('Accumulator.class.php');
 require_once('Parser.class.php');
 require_once('Query.class.php');
@@ -8,5 +10,6 @@ require_once('LogStream.class.php');
 require_once('GenericLogReader.class.php');
 require_once('SlowestQueryList.class.php');
 require_once('NormalizedQuery.class.php');
+require_once('NormalizedError.class.php');
 
 ?>
\ No newline at end of file
