@@ -41,7 +41,7 @@ class NormalizedQueriesListener extends QueryListener {
 	
 	function compareMostFrequent(& $a, & $b) {
 		if($a->getTimesExecuted() == $b->getTimesExecuted()) {
-			return 0;
+			return $this->compareSlowest($a, $b);
 		} elseif($a->getTimesExecuted() < $b->getTimesExecuted()) {
 			return 1;
 		} else {
@@ -57,7 +57,7 @@ class NormalizedQueriesListener extends QueryListener {
 	
 	function compareSlowest(& $a, & $b) {
 		if($a->getAverageDuration() == $b->getAverageDuration()) {
-			return 0;
+			return $this->compareMostFrequent($a, $b);
 		} elseif($a->getAverageDuration() < $b->getAverageDuration()) {
 			return 1;
 		} else {
