@@ -9,7 +9,7 @@ class PostgreSQLDurationLine extends PostgreSQLLogLine {
 	
 	function appendTo(& $queries) {
 		$query =& $queries->last();
-		if($query) {
+		if($query && ($query->getCommandNumber() == $this->commandNumber)) {
 			$query->setDuration($this->duration);
 			return $queries->pop();
 		} else {
