@@ -6,7 +6,7 @@ class NormalizedQueriesMostTimeReport extends NormalizedReport {
 	}
 	
 	function getText() {
-		$listener = $this->reportAggregator->getListener('NormalizedQueriesListener');
+		$listener =& $this->reportAggregator->getListener('NormalizedQueriesListener');
 		$text = '';
 		
 		$queries =& $listener->getQueriesMostTime();
@@ -22,7 +22,7 @@ class NormalizedQueriesMostTimeReport extends NormalizedReport {
 	}
 	
 	function getHtml() {
-		$listener = $this->reportAggregator->getListener('NormalizedQueriesListener');
+		$listener =& $this->reportAggregator->getListener('NormalizedQueriesListener');
 		$html = '
 <table class="queryList">
 	<tr>
