@@ -1,7 +1,7 @@
 #! /usr/bin/php -qC
 <?php
 
-define('VERSION', '0.1');
+define('VERSION', '0.2');
 
 ini_set('max_execution_time', 7200);
 error_reporting(E_ALL);
@@ -18,13 +18,19 @@ function usage($error = false) {
 	if($error) {
 		stderr('Error: '.$error);
 	}
-	echo 'Usage: '.$GLOBALS['executable'].' -file <file> [-top <n>] [-format <format>] [-logtype <logtype>]
-  -file <file>          log file to analyze
-  -top <n>              number of queries in lists. Default is 20.
-  -format <format>      output format: html or text. Default is html.
-  -logtype <logtype>    log type: only syslog is currently supported
-  -debug                debug mode
-  -help                 this help
+	echo 'Usage: '.$GLOBALS['executable'].' -file <file> [-top <n>] [-format <format>] [-logtype <logtype>] [-reports <report1,report2>]
+  -file <file>                  log file to analyze
+  -top <n>                      number of queries in lists. Default is 20.
+  -format <format>              output format: html or text. Default is html.
+  -logtype <logtype>            log type: only syslog is currently supported
+  -reports <report1,report2>    list of reports type separated by a comma
+                                reports can be: overall, bytype, slowest, n-mosttime,
+                                 n-mostfrequent, n-slowestaverage, n-mostfrequenterrors
+  -examples <n>                 maximum number of examples for a normalized query
+  -onlyselect                   ignore all queries but SELECT
+  -debug                        debug mode
+  -profile                      profile mode
+  -help                         this help
 ';
 	if($error) {
 		exit(1);
@@ -60,6 +66,11 @@ if(isset($options['debug'])) {
 } else {
 	define('DEBUG', 0);
 }
+if(isset($options['profile'])) {
+	define('PROFILE', 1);
+} else {
+	define('PROFILE', 0);
+}
 
 if(!isset($options['file'])) {
 	usage('the -file option is required');
@@ -80,7 +91,7 @@ if(isset($options['top'])) {
 } else {
 	$top = 20;
 }
-define('DEFAULT_TOP_QUERIES_NUMBER', $top);
+setConfig('default_top_queries_number', $top);
 
 $supportedFormats = array('text' => 'TextReportAggregator', 'html' => 'HtmlReportAggregator');
 if(isset($options['format'])) {
@@ -104,16 +115,50 @@ if(isset($options['logtype'])) {
 	$parser = $supportedLogTypes['syslog'];
 }
 
+$supportedReports = array(
+	'overall' => 'OverallStatsReport',
+	'bytype' => 'QueriesByTypeReport',
+	'slowest' => 'SlowestQueriesReport',
+	'n-mosttime' => 'NormalizedQueriesMostTimeReport',
+	'n-mostfrequent' => 'NormalizedQueriesMostFrequentReport',
+	'n-slowestaverage' => 'NormalizedQueriesSlowestAverageReport',
+	'n-mostfrequenterrors' => 'NormalizedErrorsMostFrequentReport',
+);
+$defaultReports = array('overall', 'bytype', 'slowest', 'n-mosttime', 'n-mostfrequent', 'n-slowestaverage');
+
+if(isset($options['reports'])) {
+	$selectedReports = explode(',', $options['reports']);
+	
+	$notSupportedReports = array_diff($selectedReports, array_keys($supportedReports));
+	if(empty($notSupportedReports)) {
+		$reports = $selectedReports;
+	} else {
+		usage('report types not supported: '.implode(',', $notSupportedReports));
+	}
+} else {
+	$reports = $defaultReports;
+}
+
+if(isset($options['examples'])) {
+	$maxExamples = (int) $options['examples'];
+} else {
+	$maxExamples = 3;
+}
+setConfig('max_number_of_examples', $maxExamples);
+
+if(isset($options['onlyselect'])) {
+	setConfig('only_select', true);
+} else {
+	setConfig('only_select', false);
+}
+
 $logReader = new GenericLogReader($filePath, $parser, 'PostgreSQLAccumulator');
 
 $reportAggregator = new $aggregator($logReader);
 
-$reportAggregator->addReport('OverallStatsReport');
-$reportAggregator->addReport('QueriesByTypeReport');
-$reportAggregator->addReport('SlowestQueriesReport');
-$reportAggregator->addReport('NormalizedQueriesMostTimeReport');
-$reportAggregator->addReport('NormalizedQueriesMostFrequentReport');
-$reportAggregator->addReport('NormalizedQueriesSlowestAverageReport');
+foreach($reports AS $report) {
+	$reportAggregator->addReport($supportedReports[$report]);
+}
 
 echo $reportAggregator->getOutput();
 
